@@ -20,6 +20,8 @@ SOCIAL_DISTANCING_DATA = DATA_INTAKE_J_DIR / 'social distancing'
 CFR_AGE_MAX_PLANCK_DATA = DATA_INTAKE_J_DIR / 'CFR-age/MaxPlanck'
 HHS_DATA = DATA_INTAKE_J_DIR / 'hhs'
 VACCINE_DATA = DATA_INTAKE_J_DIR / 'vaccine'
+MEXICO_CFR_AGE = DATA_INTAKE_J_DIR / 'data' / 'out' / 'cfr-age' / 'mexico' / 'latest'
+MEXICO_HFR_AGE = DATA_INTAKE_J_DIR / 'data' / 'out' / 'hospitalization-age' / 'mexico' / 'latest'
 
 # Shared paths
 EXEC_R_SCRIPT_PATH = Path('/share/singularity-images/lbd/shells/singR.sh')
@@ -84,6 +86,8 @@ CFR_AGE_DIR_NAME = Path('cfr_age')
 CFR_AGE_MAX_PLANCK_DIR_NAME = Path('MaxPlanck')
 HHS_DIR_NAME = Path('hhs_data')
 VACCINE_DIR_NAME = Path('vaccine')
+MEXICO_CFR_AGE_DIR_NAME = Path('mexico_cfr_age')
+MEXICO_HFR_AGE_DIR_NAME = Path('mexico_hfr_age')
 
 LOG_DIR = Path("logs")
 LOG_FILE_NAME = Path("master_log.txt")
